@@ -45,17 +45,28 @@ class Run:
 
         # item에 key값이 “timestamp” 이고 value가 현재시각 (time.time())인 item도 추가
         # item에 로그의 key value값의 쌍이 들어가도록 item을 추가ex) log({“loss” :0.03, “acc” :0.97}) -> key가 loss 이고 value가 0.03인 item과 key가 acc이고 value가 0.97인 item이 추가됨
-        # TODO : value값이 Image, Table, Chart 인경우 value값에 각 객체를 json으로 변환한 값을 추가한다.( 각 객체의 to_json호출) ##
-        from deepdriver.sdk.data_types.table import Table
 
 
+        from deepdriver.sdk.data_types.image import Image
+        from deepdriver.sdk.data_types.table import Table
+        from deepdriver.sdk.chart.chart import Chart
+
         for key, value in data.items():
             # TODO: Image, Chart등 다른 데이터 형식도 추가해야함
             if isinstance(value, Table):
                 data[key] = value.to_json(key)
-                logger.debug(f"Bable을 str(json)로 변환 변환 : {data[key]}")
-                # TODO : Upload File
+                logger.debug(f"Table을 str(json)로 변환 변환 : {data[key]}")
                 value.upload_file(self, key)
+            elif isinstance(value, Image):
+                data[key] = value.to_json(key)
+                logger.debug(f"Image를 str(json)로 변환 변환 : {data[key]}")
+                value.upload_file(self, key)
+            elif isinstance(value, Chart):
+                data[key] = value.to_json(key)
+                logger.debug(f"Chart를 str(json)로 변환 변환 : {data[key]}")
+                value.upload_file(self, key)
+
+
 
 
 
