@@ -5,8 +5,7 @@ from  urllib.parse import ParseResult
 from typing import Dict
 
 from deepdriver.sdk import util
-
-logger = logging.getLogger("deepdriver")
+from deepdriver import logger
 
 URL_LOGIN = "/api/client/auth"
 URL_CREATE = "/api/client/experiment/create"
