@@ -30,7 +30,7 @@ def get_artifact(name: str, type: str, tag: str="", team_name: str="", exp_name:
     logger.info("artifact is got! \n artifact id :{%d}"%(artifact_id))
     entry_list = []
     for entry in artifact_record.artifact_entry:
-        entry_list.append(ArtifactEntry(entry.path, "", entry.size, entry.digest, status="ADD"))
+        entry_list.append(ArtifactEntry(entry.path, "", entry.size, entry.digest, status="ADD", lfs_yn=entry.lfsYN, repo_tag=entry.repoTag))
     return Artifacts(artifact_record.name, artifact_record.type,
         id=artifact_id,
         desc=artifact_record.description,
