@@ -5,9 +5,10 @@ from assertpy import assert_that
 
 from deepdriver.sdk.chart.chart import Chart
 from deepdriver.sdk.data_types.table import Table
+from deepdriver.sdk.data_types.image import Image
 
 
-def visualize(obj: Union[Chart, Table]) -> None:
+def visualize(obj: Union[Chart, Table, Image]) -> None:
     assert_that(obj).is_not_none()
 
     if isinstance(obj, Chart):
@@ -22,7 +23,6 @@ def visualize(obj: Union[Chart, Table]) -> None:
             title=obj.label_fields["title"],
         )
         fig.show()
-
     elif isinstance(obj, Table):
         # from IPython.core.display import display, HTML
         # display(HTML(obj.data.dataframe._repr_html_()))
@@ -37,3 +37,14 @@ def visualize(obj: Union[Chart, Table]) -> None:
                   ],
         )
         fig.show()
+    elif isinstance(obj, Image):
+        # from IPython.core.display import display, HTML
+        # display(HTML(obj.data.dataframe._repr_html_()))
+
+        plotly_path = "plotly.express"
+        plotly_module = importlib.import_module(plotly_path)
+        import numpy as np
+        fig = plotly_module.imshow(
+            np.array(obj.data)
+        )
+        fig.show()
